@@ -4,7 +4,7 @@ var dir_0c50c097c08cb551fbc386ff78d6683e =
     [ "xml", "dir_fc49ab4d2f4abe8832fbad9e7c37cc2a.html", "dir_fc49ab4d2f4abe8832fbad9e7c37cc2a" ],
     [ "yum", "dir_7f8e18dcd85ffefa03157015c61c4be2.html", "dir_7f8e18dcd85ffefa03157015c61c4be2" ],
     [ "HistoryLogReader.cc", "HistoryLogReader_8cc.html", "HistoryLogReader_8cc" ],
-    [ "HistoryLogReader.h", "HistoryLogReader_8h.html", "HistoryLogReader_8h" ],
+    [ "HistoryLogReader.h", "HistoryLogReader_8h.html", null ],
     [ "IniDict.h", "IniDict_8h.html", null ],
     [ "IniParser.h", "IniParser_8h.html", null ],
     [ "ParseException.h", "ParseException_8h.html", null ],
